@@ -1991,3 +1991,108 @@ compile_set_i18n( gboolean i18n )
 {
 	compile_find_i18n = i18n;
 }
+
+/* Lev's stack trace:
+
+654            switch( pn->type ) {
+(gdb) where
+#0  0x0807a1e1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddd940)
+    at compile.c:1654
+#1  0x0807a39d in compile_check_i18n (compile=0x9dbce98, pn=0x9ddd9c0)
+    at compile.c:1699
+#2  0x0807a39d in compile_check_i18n (compile=0x9dbce98, pn=0x9dddac0)
+    at compile.c:1699
+#3  0x0807a39d in compile_check_i18n (compile=0x9dbce98, pn=0x9dde980)
+    at compile.c:1699
+#4  0x0807a3f1 in compile_check_i18n (compile=0x9dbce98, pn=0x9dde9c0)
+    at compile.c:1712
+#5  0x0807a3b1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddea00)
+    at compile.c:1700
+#6  0x0807a3f1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddea40)
+    at compile.c:1712
+#7  0x0807a3b1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddea80)
+    at compile.c:1700
+#8  0x0807a3f1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddeac0)
+    at compile.c:1712
+#9  0x0807a3b1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddeb00)
+    at compile.c:1700
+#10 0x0807a3f1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddeb40)
+    at compile.c:1712
+#11 0x0807a3b1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddeb80)
+    at compile.c:1700
+#12 0x0807a3f1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddebc0)
+    at compile.c:1712
+#13 0x0807a3b1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddec00)
+    at compile.c:1700
+#14 0x0807a3f1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddec40)
+    at compile.c:1712
+#15 0x0807a3b1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddec80)
+    at compile.c:1700
+#16 0x0807a3f1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddecc0)
+    at compile.c:1712
+#17 0x0807a3b1 in compile_check_i18n (compile=0x9dbce98, pn=0x9dded00)
+    at compile.c:1700
+#18 0x0807a3f1 in compile_check_i18n (compile=0x9dbce98, pn=0x9dded40)
+    at compile.c:1712
+#19 0x0807a3b1 in compile_check_i18n (compile=0x9dbce98, pn=0x9dded80)
+    at compile.c:1700
+#20 0x0807a3f1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddedc0)
+    at compile.c:1712
+#21 0x0807a3b1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddee00)
+    at compile.c:1700
+#22 0x0807a3f1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddee40)
+    at compile.c:1712
+#23 0x0807a3b1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddee80)
+    at compile.c:1700
+#24 0x0807a3f1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddeec0)
+    at compile.c:1712
+#25 0x0807a3b1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddef00)
+    at compile.c:1700
+#26 0x0807a3f1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddef40)
+    at compile.c:1712
+#27 0x0807a3b1 in compile_check_i18n (compile=0x9dbce98, pn=0x9ddef80)
+    at compile.c:1700
+#28 0x0807a4c1 in compile_check (compile=0x9dbce98) at compile.c:1755
+#29 0x080a7874 in yyparse () at parse.y:728
+#30 0x080a8ea4 in parse_input (ch=46, sym=0x8a110bc, kit=0x8c0bcb0, pos=0)
+    at parse.y:1286
+#31 0x080a8efa in parse_toplevel (kit=0x8c0bcb0, pos=0) at parse.y:1304
+#32 0x080db5e5 in toolkit_load_text (model=0x8c0bcb0, parent=0x8a18018,
+    of=0x9da85c0) at toolkit.c:112
+#33 0x080b6035 in model_load_text (model=0x8c0bcb0, parent=0x8a18018,
+    of=0x9da85c0) at model.c:395
+#34 0x080825e4 in filemodel_load_all_text (filemodel=0x8c0bcb0,
+    parent=0x8a18018,
+    filename=0xbfbf6120 "$VIPSHOME/share/nip2/start/_stdenv.def")
+    at filemodel.c:525
+#35 0x0808265a in filemodel_load_all (filemodel=0x8c0bcb0, parent=0x8a18018,
+    filename=0xbfbf6120 "$VIPSHOME/share/nip2/start/_stdenv.def")
+    at filemodel.c:550
+#36 0x080db9a8 in toolkit_new_from_file (kitg=0x8a18018,
+    filename=0xbfbf6120 "$VIPSHOME/share/nip2/start/_stdenv.def")
+    at toolkit.c:247
+#37 0x080ac674 in main_load_def (
+    filename=0xbfbf6120 "$VIPSHOME/share/nip2/start/_stdenv.def")
+    at main.c:426
+#38 0x080bb7be in path_next_item (
+    filename=0xbfbf6120 "$VIPSHOME/share/nip2/start/_stdenv.def",
+    previous=0xbfbf65f0, fn=0x80ac620 <main_load_def>, a=0x0) at path.c:201
+#39 0x080bb641 in path_match_pattern (wild=0x8c45270,
+    dir_name=0x830a620 "$VIPSHOME/share/nip2/start",
+    name=0x8c48180 "_stdenv.def", fn=0x80bb734 <path_next_item>,
+    a=0xbfbf65f0, b=0x80ac620, c=0x0) at path.c:148
+#40 0x080bb6c7 in path_scan_dir (
+    dir_name=0x830a620 "$VIPSHOME/share/nip2/start", wild=0x8c45270,
+    fn=0x80bb734 <path_next_item>, a=0xbfbf65f0, b=0x80ac620, c=0x0)
+    at path.c:170
+#41 0x080e0d6e in slist_map5 (list=0x8318830, fn=0x80bb660 <path_scan_dir>,
+    a=0x8c45270, b=0x80bb734, c=0xbfbf65f0, d=0x80ac620, e=0x0) at util.c:575
+#42 0x080bb82f in path_map_exact (path=0x8318830, patt=0x80fee03 "*.def",
+    fn=0x80ac620 <main_load_def>, a=0x0) at path.c:230
+#43 0x080aca33 in main_load_startup () at main.c:549
+#44 0x080ad988 in main (argc=1, argv=0xbfbfecf4) at main.c:1177
+(gdb) quit
+
+ */
+
+
