@@ -567,8 +567,18 @@ filesel_set_filename( Filesel *filesel, const char *name )
         nativeize_path( buf );
 	absoluteize_path( buf );
 	filesel_set_filetype_from_filename( filesel, buf );
+
+	/* set_filename() will only select existing files, we need to be able
+	 * to set any filename (eg. for increment filename), so we have to
+	 * set_current_name() as well.
+	 */
 	gtk_file_chooser_set_filename( 
 		GTK_FILE_CHOOSER( filesel->chooser ), buf );
+	if( filesel->save )
+		gtk_file_chooser_set_current_name(
+			GTK_FILE_CHOOSER( filesel->chooser ), 
+			im_skip_dir( buf ) );
+
 	filesel->start_name = TRUE;
 
 	return( TRUE );
@@ -628,11 +638,16 @@ filesel_selection_changed_cb( GtkWidget *widget, gpointer data )
         char *filename;
 
 #ifdef DEBUG
-	printf( "filesel_selection_changed_cb: %s - \"%s\"\n", 
-		NN( IWINDOW( filesel )->title ), NN( filename ) );
+	printf( "filesel_selection_changed_cb: %s\n", 
+		NN( IWINDOW( filesel )->title ) );
 #endif /*DEBUG*/
 
 	if( (filename = filesel_get_filename( filesel )) ) {
+#ifdef DEBUG
+		printf( "filesel_selection_changed_cb: %s - \"%s\"\n", 
+			NN( IWINDOW( filesel )->title ), filename );
+#endif /*DEBUG*/
+
 		filesel_info_update( filesel, filename );
 		g_free( filename );
 	}
