@@ -40,7 +40,7 @@ static iWindowClass *parent_class = NULL;
 void
 idialog_free_client( iDialog *idlg, void *client )
 {
-	FREE( client );
+	IM_FREE( client );
 }
 
 /* Notify our parent.
@@ -70,7 +70,7 @@ void
 idialog_set_ok_button_state( iDialog *idlg, gboolean state )
 {
 	slist_map( idlg->ok_l, 
-		(SListMapFn) idialog_set_sensitive, (void *) state );
+		(SListMapFn) idialog_set_sensitive, GINT_TO_POINTER( state ) );
 }
 
 /* Set all the button sensitivities.
@@ -290,9 +290,9 @@ idialog_destroy( GtkObject *object )
 	FREESID( idlg->parent_sid, idlg->parent );
 	FREESID( idlg->destroy_sid, idlg->iobject );
 	slist_map( idlg->ok_txt_l, (SListMapFn) im_free, NULL );
-	FREEF( g_slist_free, idlg->ok_cb_l );
-	FREEF( g_slist_free, idlg->ok_txt_l );
-	FREEF( g_slist_free, idlg->ok_l );
+	IM_FREEF( g_slist_free, idlg->ok_cb_l );
+	IM_FREEF( g_slist_free, idlg->ok_txt_l );
+	IM_FREEF( g_slist_free, idlg->ok_l );
 
 	GTK_OBJECT_CLASS( parent_class )->destroy( object );
 }
@@ -338,6 +338,10 @@ idialog_iobject_destroy( iObject *iobject, iDialog *idlg )
 	printf( "idialog_iobject_destroy: %s\n", IWINDOW( idlg )->title );
 #endif /*DEBUG*/
 
+	/* This object has gone.
+	 */
+	idlg->iobject = NULL;
+
 	iwindow_kill( IWINDOW( idlg ) );
 }
 
@@ -686,7 +690,8 @@ idialog_add_ok( iDialog *idlg, iWindowFn done_cb, const char *fmt, ... )
 	 * the list). [OK1, OK2, OK3, OK4]
 	 */
 	idlg->ok_cb_l = g_slist_prepend( idlg->ok_cb_l, (void *) done_cb );
-	idlg->ok_txt_l = g_slist_prepend( idlg->ok_txt_l, g_strdup( buf ) );
+	idlg->ok_txt_l = 
+		g_slist_prepend( idlg->ok_txt_l, im_strdup( NULL, buf ) );
 }
 
 void 
