@@ -651,7 +651,16 @@ main_register_icons( void )
 		{ STOCK_MOVE, N_( "Pan" ), 
 			0, 0, GETTEXT_PACKAGE },
 		{ STOCK_SELECT, N_( "Select" ), 
-			0, 0, GETTEXT_PACKAGE }
+			0, 0, GETTEXT_PACKAGE },
+
+		/* And the LEDs we use.
+		 */
+		{ STOCK_LED_RED, N_( "Red LED" ), 0, 0, GETTEXT_PACKAGE },
+		{ STOCK_LED_GREEN, N_( "Green LED" ), 0, 0, GETTEXT_PACKAGE },
+		{ STOCK_LED_BLUE, N_( "Blue LED" ), 0, 0, GETTEXT_PACKAGE },
+		{ STOCK_LED_YELLOW, N_( "Yellow LED" ), 0, 0, GETTEXT_PACKAGE },
+		{ STOCK_LED_CYAN, N_( "Cyan LED" ), 0, 0, GETTEXT_PACKAGE },
+		{ STOCK_LED_OFF, N_( "Off LED" ), 0, 0, GETTEXT_PACKAGE }
 	};
 
 	GtkIconSet *icon_set;
@@ -691,6 +700,18 @@ main_register_icons( void )
 		STOCK_MOVE, "stock-tool-move-22.png" );
 	main_file_for_stock( main_icon_factory, 
 		STOCK_SELECT, "stock-tool-select-22.png" );
+	main_file_for_stock( main_icon_factory, 
+		STOCK_LED_RED, "stock-led-red-18.png" );
+	main_file_for_stock( main_icon_factory, 
+		STOCK_LED_GREEN, "stock-led-green-18.png" );
+	main_file_for_stock( main_icon_factory, 
+		STOCK_LED_BLUE, "stock-led-blue-18.png" );
+	main_file_for_stock( main_icon_factory, 
+		STOCK_LED_YELLOW, "stock-led-yellow-18.png" );
+	main_file_for_stock( main_icon_factory, 
+		STOCK_LED_CYAN, "stock-led-cyan-18.png" );
+	main_file_for_stock( main_icon_factory, 
+		STOCK_LED_OFF, "stock-led-off-18.png" );
 
 	gtk_icon_factory_add_default( main_icon_factory );
 	g_object_unref( main_icon_factory );
