@@ -78,9 +78,12 @@ struct _Mainw {
 	/* Component widgets.
 	 */
 	Toolkitgroupview *kitgview;
+	Toolkitbrowser *toolkitbrowser;
 	Workspaceview *wsview;
-	GtkItemFactory *ifac;
+	GtkActionGroup *action_group;
+	GtkUIManager *ui_manager;
 	GtkWidget *toolbar;
+	GtkWidget *recent_menu;
 
 	GtkWidget *statusbar_main;
 	GtkWidget *statusbar;
@@ -89,7 +92,7 @@ struct _Mainw {
 
 	GtkWidget *pane;
 	gboolean pane_last_visible;	/* Current widget state */
-	int pane_position;		/* Saved position */
+	int pane_position;		
 	int target_position;		/* Animating towards this pos */
 	int last_set_position;		/* The last one we set ... for sanity */
 	guint pane_animate_timeout;	/* With this timeout */
@@ -115,5 +118,8 @@ void mainw_recent_add( GSList **recent, const char *filename );
 int mainw_number( void );
 Mainw *mainw_pick_one( void );
 GType mainw_get_type( void );
+void mainw_about_action_cb( GtkAction *action, iWindow *iwnd );
+void mainw_guide_action_cb( GtkAction *action, iWindow *iwnd );
 Filemodel *mainw_open_file( Mainw *mainw, const char *filename );
 Mainw *mainw_new( Workspace *ws );
+
