@@ -1198,11 +1198,13 @@ iscaseprefix( const char *a, const char *b )
 	return( TRUE );
 }
 
-#ifndef HAVE_STRCASESTR
-/* Like strstr(), but case-insensitive.
+/* Like strstr(), but case-insensitive. 
+ * 
+ * It's awkward to test for, since sometimes you need to add extra flags to
+ * enable it in headers :-( Define our own for simplicity. 
  */
 char *
-strcasestr( const char *haystack, const char *needle )
+my_strcasestr( const char *haystack, const char *needle )
 {
 	int i;
 	int hlen = strlen( haystack );
@@ -1214,7 +1216,6 @@ strcasestr( const char *haystack, const char *needle )
 
 	return( NULL );
 }
-#endif /*!HAVE_STRCASESTR*/
 
 /* Copy a string, interpreting (a few) C-language escape codes.
 
