@@ -161,7 +161,8 @@ workspaceview_set_cursor( Workspaceview *wview, iWindowShape shape )
 {
 	if( !wview->context ) 
 		wview->context = iwindow_cursor_context_new( 
-			IWINDOW( view_get_toplevel( VIEW( wview ) ) ) );
+			IWINDOW( view_get_toplevel( VIEW( wview ) ) ), 0, 
+			"workspaceview" );
 
 	iwindow_cursor_context_set_cursor( wview->context, shape );
 }
@@ -332,7 +333,7 @@ workspaceview_scroll_time_cb( Workspaceview *wview )
 static void
 workspaceview_scroll_stop( Workspaceview *wview )
 {	
-        FREEFI( g_source_remove, wview->timer );
+        IM_FREEF( g_source_remove, wview->timer );
 }
 
 /* Start the tally_scroll timer.
@@ -376,7 +377,7 @@ workspaceview_destroy( GtkObject *object )
 	/* Instance destroy.
 	 */
 	workspaceview_scroll_stop( wview );
-	FREEF( iwindow_cursor_context_destroy, wview->context );
+	IM_FREEF( iwindow_cursor_context_destroy, wview->context );
 	FREESID( wview->watch_changed_sid, main_watchgroup );
 
 	GTK_OBJECT_CLASS( parent_class )->destroy( object );
@@ -423,7 +424,7 @@ workspaceview_drag_data_received( GtkWidget *widget, GdkDragContext *context,
 		name = workspace_column_name_new( ws, NULL );
 		if( !(col = column_new( ws, name )) )
 			box_alert( widget );
-		FREE( name );
+		IM_FREE( name );
 
 		if( col ) {
 			char buf_text[256];
